@@ -32,7 +32,7 @@ $charset				= 'UTF-8';			// Character set your calendar is in, suggested UTF-8,
 $allow_webcals 			= 'no';				// Allow http:// and webcal:// prefixed URLs to be used as the $cal for remote viewing of "subscribe-able" calendars. This does not have to be enabled to allow specific ones below.
 $this_months_events 	= 'yes';			// Display "This month's events" at the bottom off the month page.
 $enable_rss				= 'yes';			// Enable RSS access to your calendars (good thing).
-$show_search			= 'yes';			// Show the search box in the sidebar.
+$show_search			= 'no';			// Show the search box in the sidebar.
 $allow_preferences		= 'yes';			// Allow visitors to change various preferences via cookies.
 $printview_default		= 'no';				// Set print view as the default view. day, week, and month only supported views for $default_view (listed well above).
 $show_todos				= 'yes';			// Show your todo list on the side of day and week view.
