@@ -150,7 +150,7 @@ foreach ($cal_filelist as $filename) {
 				unset (
 					$start_time, $end_time, $start_date, $end_date, $summary, 
 					$allday_start, $allday_end, $start, $end, $the_duration, 
-					$beginning, $rrule_array, $start_of_vevent, $description, $bd, $url, 
+					$beginning, $rrule_array, $start_of_vevent, $description, $url, 
 					$valarm_description, $start_unixtime, $end_unixtime, $display_end_tmp, $end_time_tmp1, 
 					$recurrence_id, $uid, $class, $location, $rrule, $abs_until, $until_check,
 					$until, $bymonth, $byday, $bymonthday, $byweek, $byweekno, 
@@ -309,7 +309,7 @@ foreach ($cal_filelist as $filename) {
 				
 				// Handling regular events
 				if ((isset($start_time) && $start_time != '') && (!isset($allday_start) || $allday_start == '')) {
-					if (($end_time > $bleed_time) && ($bleed_check == '-1')) {
+					if (($end_time >= $bleed_time) && ($bleed_check == '-1')) {
 						$start_tmp = strtotime(date('Ymd',$start_unixtime));
 						$end_date_tmp = date('Ymd',$end_unixtime);
 						while ($start_tmp < $end_unixtime) {
@@ -328,8 +328,8 @@ foreach ($cal_filelist as $filename) {
 								$display_end_tmp = $end_time;
 							}
 							
-							$nbrOfOverlaps = checkOverlap($start_date_tmp, $start_time_tmp, $end_time_tmp, $uid);
-							$master_array[$start_date_tmp][$time_tmp][$uid] = array ('event_start' => $start_time_tmp, 'event_end' => $end_time_tmp, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime, 'end_unixtime' => $end_unixtime, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => $nbrOfOverlaps, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => true, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url );
+							$master_array[$start_date_tmp][$time_tmp][$uid] = array ('event_start' => $start_time_tmp, 'event_end' => $end_time_tmp, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime, 'end_unixtime' => $end_unixtime, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => 0, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => true, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url );
+							checkOverlap($start_date_tmp, $time_tmp, $uid);
 							$start_tmp = strtotime('+1 day',$start_tmp);
 						}
 						if (!$write_processed) $master_array[$start_date][($hour.$minute)][$uid]['exception'] = true;
@@ -343,8 +343,8 @@ foreach ($cal_filelist as $filename) {
 					
 						// This if statement should prevent writing of an excluded date if its the first recurrance - CL
 						if (!in_array($start_date, $except_dates)) {
-							$nbrOfOverlaps = checkOverlap($start_date, $start_time, $end_time_tmp1, $uid);
-							$master_array[($start_date)][($hour.$minute)][$uid] = array ('event_start' => $start_time, 'event_end' => $end_time_tmp1, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime, 'end_unixtime' => $end_unixtime, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => $nbrOfOverlaps, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => false, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url );
+							$master_array[($start_date)][($hour.$minute)][$uid] = array ('event_start' => $start_time, 'event_end' => $end_time_tmp1, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime, 'end_unixtime' => $end_unixtime, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => 0, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => false, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url );
+							checkOverlap($start_date, ($hour.$minute), $uid);
 							if (!$write_processed) $master_array[($start_date)][($hour.$minute)][$uid]['exception'] = true;
 						}
 					}
@@ -374,7 +374,7 @@ foreach ($cal_filelist as $filename) {
 					
 					$start_date_time = strtotime($start_date);
 					$this_month_start_time = strtotime($this_year.$this_month.'01');
-					if ($save_parsed_cals == 'yes' && !$is_webcal) {
+					if ($current_view == 'year' || ($save_parsed_cals == 'yes' && !$is_webcal)) {
 						$start_range_time = strtotime($this_year.'-01-01 -2 weeks');
 						$end_range_time = strtotime($this_year.'-12-31 +2 weeks');
 					} else {
@@ -462,7 +462,9 @@ foreach ($cal_filelist as $filename) {
 								$master_array[($start_date)][($hour.$minute)][$uid]['recur'][$key] = $wkst;
 								break;
 							case 'END':
-							
+
+							$recur = $master_array[($start_date)][($hour.$minute)][$uid]['recur'];
+
 							// Modify the COUNT based on BYDAY
 							if ((is_array($byday)) && (isset($count))) {
 								$blah = sizeof($byday);
@@ -479,12 +481,6 @@ foreach ($cal_filelist as $filename) {
 							$start_range_time_tmp = $start_range_time;
 							$end_range_time_tmp = $end_range_time;
 							
-							// For weekly's without a byday
-							if ((!isset($byday)) && ($rrule_array['FREQ'] == 'WEEKLY')) {
-								ereg ('([0-9]{4})([0-9]{2})([0-9]{2})', $start_date, $startregs);
-								$bd = strtolower(date ("l", mktime($hour,$minute,0,$startregs[2],$startregs[3],$startregs[1])));
-							}
-							
 							// If the $end_range_time is less than the $start_date_time, or $start_range_time is greater
 							// than $end_date_time, we may as well forget the whole thing
 							// It doesn't do us any good to spend time adding data we aren't even looking at
@@ -495,7 +491,7 @@ foreach ($cal_filelist as $filename) {
 								if ($start_range_time_tmp < $start_date_time) $start_range_time_tmp = $start_date_time;
 								if ($end_range_time_tmp > $end_date_time) $end_range_time_tmp = $end_date_time;
 					
-								// initialze the time we will increment
+								// initialize the time we will increment
 								$next_range_time = $start_range_time_tmp;
 								
 								// FIXME: This is a hack to fix repetitions with $interval > 1 
@@ -515,15 +511,20 @@ foreach ($cal_filelist as $filename) {
 													$recur_data[] = $next_date_time;
 													break;
 												case 'WEEKLY':
+													// Populate $byday with the default day if it's not set.
 													if (!isset($byday)) {
-														$next_date = dateOfWeek(date('Ymd', $next_range_time),$bd);
-														$next_date_time = strtotime($next_date);
-														$recur_data[] = $next_date_time;
-													} elseif (is_array($byday)) {
+														$byday[] = strtoupper(substr($daysofweekshort_lang[date('w', $start_date_time)], 0, 2));
+													}
+													if (is_array($byday)) {
 														foreach($byday as $day) {
 															$day = two2threeCharDays($day);	
-															$next_date = dateOfWeek(date('Ymd', $next_range_time),$day);
-															$next_date_time = strtotime($next_date);
+															$next_date_time = strtotime($day,$next_range_time) + (12 * 60 * 60);
+															// Since this renders events from $next_range_time to $next_range_time + 1 week, I need to handle intervals
+															// as well. This checks to see if $next_date_time is after $day_start (i.e., "next week"), and thus
+															// if we need to add $interval weeks to $next_date_time.
+															if ($next_date_time > strtotime($week_start_day, $next_range_time) && $interval > 1) {
+																$next_date_time = strtotime('+'.($interval - 1).' '.$freq_type, $next_date_time);
+															}
 															$recur_data[] = $next_date_time;
 														}
 													}
@@ -534,6 +535,7 @@ foreach ($cal_filelist as $filename) {
 													$next_date_time = $next_date_time;
 													if ((isset($bymonthday)) && (!isset($byday))) {
 														foreach($bymonthday as $day) {
+															if ($day < 0) $day = ((date('t', $next_range_time)) + ($day)) + 1;
 															$year = date('Y', $next_range_time);
 															$month = date('m', $next_range_time);
 															if (checkdate($month,$day,$year)) {
@@ -590,12 +592,15 @@ foreach ($cal_filelist as $filename) {
 														$m = date('m', $start_date_time);
 														$bymonth = array("$m");
 													}	
+
 													foreach($bymonth as $month) {
-														// FIXME: Jan 1 does not display in December
-														$year = date('Y', $next_range_time);
-														if (($year != $this_year) && ($month < 3)) {
-															$year = $this_year;
+														// Make sure the month & year used is within the start/end_range.
+														if ($month < date('m', $next_range_time)) {
+															$year = date('Y', strtotime('+1 years', $next_range_time));
+														} else {
+															$year = date('Y', $next_range_time);
 														}
+
 														if ((isset($byday)) && (is_array($byday))) {
 															$checkdate_time = mktime(0,0,0,$month,1,$year);
 															foreach($byday as $day) {
@@ -668,14 +673,14 @@ foreach ($cal_filelist as $filename) {
 													$end_time2 = strtotime('+'.$diff_allday_days.' days', $recur_data_time);
 													while ($start_time2 < $end_time2) {
 														$start_date2 = date('Ymd', $start_time2);
-														$master_array[($start_date2)][('-1')][] = array ('event_text' => $summary, 'description' => $description, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url, 'status' => $status, 'class' => $class );
+														$master_array[($start_date2)][('-1')][$uid] = array ('event_text' => $summary, 'description' => $description, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url, 'status' => $status, 'class' => $class, 'recur' => $recur );
 														$start_time2 = strtotime('+1 day', $start_time2);
 													}
 												} else {
 													$start_unixtime_tmp = mktime($recur_data_hour,$recur_data_minute,0,$recur_data_month,$recur_data_day,$recur_data_year);
 													$end_unixtime_tmp = $start_unixtime_tmp + $length;
 													
-													if (($end_time > $bleed_time) && ($bleed_check == '-1')) {
+													if (($end_time >= $bleed_time) && ($bleed_check == '-1')) {
 														$start_tmp = strtotime(date('Ymd',$start_unixtime_tmp));
 														$end_date_tmp = date('Ymd',$end_unixtime_tmp);
 														while ($start_tmp < $end_unixtime_tmp) {
@@ -697,8 +702,8 @@ foreach ($cal_filelist as $filename) {
 															// Let's double check the until to not write past it
 															$until_check = $start_date_tmp.$time_tmp.'00';
 															if ($abs_until > $until_check) {
-																$nbrOfOverlaps = checkOverlap($start_date_tmp, $start_time_tmp, $end_time_tmp, $uid);
-																$master_array[$start_date_tmp][$time_tmp][$uid] = array ('event_start' => $start_time_tmp, 'event_end' => $end_time_tmp, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime_tmp, 'end_unixtime' => $end_unixtime_tmp, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => $nbrOfOverlaps, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => true, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url) ;
+																$master_array[$start_date_tmp][$time_tmp][$uid] = array ('event_start' => $start_time_tmp, 'event_end' => $end_time_tmp, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime_tmp, 'end_unixtime' => $end_unixtime_tmp, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => 0, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => true, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url, 'recur' => $recur);
+																checkOverlap($start_date_tmp, $time_tmp, $uid);
 															}
 															$start_tmp = strtotime('+1 day',$start_tmp);
 														}
@@ -713,8 +718,8 @@ foreach ($cal_filelist as $filename) {
 														// Let's double check the until to not write past it
 														$until_check = $recur_data_date.$hour.$minute.'00';
 														if ($abs_until > $until_check) {
-															$nbrOfOverlaps = checkOverlap($recur_data_date, $start_time, $end_time_tmp1, $uid);
-															$master_array[($recur_data_date)][($hour.$minute)][$uid] = array ('event_start' => $start_time, 'event_end' => $end_time_tmp1, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime_tmp, 'end_unixtime' => $end_unixtime_tmp, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => $nbrOfOverlaps, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => false, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url);
+															$master_array[($recur_data_date)][($hour.$minute)][$uid] = array ('event_start' => $start_time, 'event_end' => $end_time_tmp1, 'display_end' => $display_end_tmp, 'start_unixtime' => $start_unixtime_tmp, 'end_unixtime' => $end_unixtime_tmp, 'event_text' => $summary, 'event_length' => $length, 'event_overlap' => 0, 'description' => $description, 'status' => $status, 'class' => $class, 'spans_day' => false, 'location' => $location, 'organizer' => serialize($organizer), 'attendee' => serialize($attendee), 'calnumber' => $calnumber, 'calname' => $actual_calname, 'url' => $url, 'recur' => $recur);
+															checkOverlap($recur_data_date, ($hour.$minute), $uid);
 														}
 													}
 												}
@@ -744,7 +749,7 @@ foreach ($cal_filelist as $filename) {
 				}
 				
 			   // Clear event data now that it's been saved.
-			   unset($start_time, $start_time_tmp, $end_time, $end_time_tmp, $start_unixtime, $start_unixtime_tmp, $end_unixtime, $end_unixtime_tmp, $summary, $length, $nbrOfOverlaps, $description, $status, $class, $location, $organizer, $attendee);
+			   unset($start_time, $start_time_tmp, $end_time, $end_time_tmp, $start_unixtime, $start_unixtime_tmp, $end_unixtime, $end_unixtime_tmp, $summary, $length, $description, $status, $class, $location, $organizer, $attendee);
 
 				break;
 			case 'END:VTODO':
@@ -755,6 +760,18 @@ foreach ($cal_filelist as $filename) {
 				} else {
 					$vtodo_sort = $vtodo_priority;
 				}
+				
+				// CLASS support
+				if (isset($class)) {
+					if ($class == 'PRIVATE') {
+						$summary = '**PRIVATE**';
+						$description = '**PRIVATE**';
+					} elseif ($class == 'CONFIDENTIAL') {
+						$summary = '**CONFIDENTIAL**';
+						$description = '**CONFIDENTIAL**';
+					}
+				}
+				
 				$master_array['-2']["$vtodo_sort"]["$uid"] = array ('start_date' => $start_date, 'start_time' => $start_time, 'vtodo_text' => $summary, 'due_date'=> $due_date, 'due_time'=> $due_time, 'completed_date' => $completed_date, 'completed_time' => $completed_time, 'priority' => $vtodo_priority, 'status' => $status, 'class' => $class, 'categories' => $vtodo_categories, 'description' => $description, 'calname' => $actual_calname);
 				unset ($start_date, $start_time, $due_date, $due_time, $completed_date, $completed_time, $vtodo_priority, $status, $class, $vtodo_categories, $summary, $description);
 				$vtodo_set = FALSE;
@@ -926,6 +943,9 @@ foreach ($cal_filelist as $filename) {
 							}
 			
 							preg_match ('/([0-9]{4})([0-9]{2})([0-9]{2})([0-9]{0,2})([0-9]{0,2})/', $data, $regs);
+							if ($regs[1] < 1970) { 
+								$regs[1] = '1971';
+							}
 							$start_date = $regs[1] . $regs[2] . $regs[3];
 							$start_time = $regs[4] . $regs[5];
 							$start_unixtime = mktime($regs[4], $regs[5], 0, $regs[2], $regs[3], $regs[1]);
@@ -977,6 +997,9 @@ foreach ($cal_filelist as $filename) {
 							}
 							
 							preg_match ('/([0-9]{4})([0-9]{2})([0-9]{2})([0-9]{0,2})([0-9]{0,2})/', $data, $regs);
+							if ($regs[1] < 1970) { 
+								$regs[1] = '1971';
+							}
 							$end_date = $regs[1] . $regs[2] . $regs[3];
 							$end_time = $regs[4] . $regs[5];
 							$end_unixtime = mktime($regs[4], $regs[5], 0, $regs[2], $regs[3], $regs[1]);
@@ -1016,6 +1039,7 @@ foreach ($cal_filelist as $filename) {
 						
 					case 'SUMMARY':
 						$data = str_replace("\\n", "<br />", $data);
+						$data = str_replace("\\t", "&nbsp;", $data);
 						$data = str_replace("\\r", "<br />", $data);
 						$data = str_replace('$', '&#36;', $data);
 						$data = htmlentities(urlencode($data));
@@ -1028,6 +1052,7 @@ foreach ($cal_filelist as $filename) {
 						
 					case 'DESCRIPTION':
 						$data = str_replace("\\n", "<br />", $data);
+						$data = str_replace("\\t", "&nbsp;", $data);
 						$data = str_replace("\\r", "<br />", $data);
 						$data = str_replace('$', '&#36;', $data);
 						$data = htmlentities(urlencode($data));
@@ -1125,6 +1150,7 @@ foreach ($cal_filelist as $filename) {
 						break;
 					case 'LOCATION':
 						$data = str_replace("\\n", "<br />", $data);
+						$data = str_replace("\\t", "&nbsp;", $data);
 						$data = str_replace("\\r", "<br />", $data);
 						$location = $data;
 						break;
@@ -1175,7 +1201,7 @@ if ($parse_file) {
 //print_r($overlap_array);
 //print_r($day_array);
 //print_r($rrule_array);
-//print_r($recurrence_delete);	
+//print_r($recurrence_delete);
 //print '</pre>';
 
 // Set a calender name for all calenders combined
@@ -1184,5 +1210,5 @@ if ($cal == $ALL_CALENDARS_COMBINED) {
 }
 
 $template_started = getmicrotime();
-					
+
 ?>
