@@ -116,6 +116,120 @@ class Page {
 		}
 	}	
 	
+	function draw_search($template_p) {
+		global $template, $getdate, $cal, $the_arr, $daysofweek_lang, $week_start_day, $printview, $dateFormat_day, $timeFormat, $week_start, $week_end, $lang;
+
+		preg_match("!<\!-- switch results on -->(.*)<\!-- switch results off -->!is", $this->page, $match1);
+		preg_match("!<\!-- switch recur on -->(.*)<\!-- loop recur off -->!is", $this->page, $match2);
+		preg_match("!<\!-- switch exceptions on -->(.*)<\!-- switch exceptions off -->!is", $this->page, $match3);
+		$loop_event		= trim($match1[1]);
+		$loop_recur 	= trim($match2[1]);
+		$loop_except 	= trim($match3[1]);
+		$parse_month 	= date ("Ym", strtotime($getdate));
+		
+		if (isset($the_arr)){
+		
+		// Pull out each event
+		foreach($the_arr as $key => $val) {
+			
+			$events_found++;
+			$dayofmonth = strtotime($val['date']);
+			$dayofmonth = localizeDate ('%A, %B %e %Y', $dayofmonth);
+			$events_tmp = $loop_event;
+			$recur_tmp	= $loop_recur;
+				
+			if ($val['event_text']) {	
+				$event_text 	= stripslashes(urldecode($val['event_text']));
+				$description 	= stripslashes(urldecode($val['description']));
+					$location 	= stripslashes(urldecode($val['location']));
+				$event_start 	= $val['event_start'];
+				$event_end 		= $val['event_end'];
+				if (isset($val['display_end'])) $event_end = $val['display_end'];
+					if (!$val['event_start']) { 
+						$event_start = $lang['l_all_day'];
+						$event_start2 = '';
+						$event_end = '';
+					} else {
+							$event_start    = date ($timeFormat, strtotime ($event_start));
+							$event_end      = date ($timeFormat, strtotime ($event_end));
+							$event_start    = $event_start .' - '.$event_end;
+					}							
+				}
+				
+				if ($description == '') {
+					$events_tmp = preg_replace('!<\!-- switch description_events on -->(.*)<\!-- switch description_events off -->!is', '', $events_tmp);
+				}
+					if (!isset($val['exceptions'])) {
+					$events_tmp = preg_replace('!<\!-- switch exceptions on -->(.*)<\!-- switch exceptions off -->!is', '', $events_tmp);
+				}else{
+						$some_exceptions = "";
+						foreach ($val['exceptions'] as $except_val){
+							$except_tmp	= $loop_except;
+							
+							$except_date = strtotime($except_val['date']);
+							$except_date = localizeDate ('%A, %B %e %Y', $except_date);
+							$except_tmp = str_replace('{DAYOFMONTH}', $except_date, $except_tmp);
+
+							$except_event_start    	= date ($timeFormat, strtotime ($except_val['event_start']));
+							$except_event_end    	= date ($timeFormat, strtotime ($except_val['event_end']));
+							$except_event_start    	= $except_event_start .' - '.$except_event_end;
+
+							$except_tmp = str_replace('{EVENT_START}', $except_event_start, $except_tmp);
+
+							$except_event_text 	= stripslashes(urldecode($except_val['event_text']));
+							$except_tmp = str_replace('{EVENT_TEXT}', $except_event_text, $except_tmp);
+
+							#is there a recur in the exception?
+							if (!$except_val['recur']) {
+								$except_tmp = preg_replace('!<\!-- switch except_recur on -->(.*)<\!-- switch except_recur off -->!is', '', $except_tmp);
+							}else{
+								$except_tmp = str_replace('{EXCEPT_RECUR}', $except_val['recur'], $except_tmp);
+							}
+							#is there a description in the exception?
+							if (!$except_val['description']) {
+								$except_tmp = preg_replace('!<\!-- switch except_description on -->(.*)<\!-- switch except_description off -->!is', '', $except_tmp);
+							}else{
+								$except_description = stripslashes(urldecode($except_val['description']));
+								$except_tmp = str_replace('{EXCEPT_DESCRIPTION}', $except_description, $except_tmp);
+							}
+							$some_exceptions .= $except_tmp;
+	
+						}
+						$events_tmp = preg_replace('!<\!-- switch exceptions on -->(.*)<\!-- switch exceptions off -->!is', $some_exceptions,$events_tmp );
+
+	
+				}
+				
+				if (!$val['recur']) {
+					$events_tmp = preg_replace('!<\!-- switch recur on -->(.*)<\!-- switch recur off -->!is', '', $events_tmp);
+				}else{
+					$events_tmp = str_replace('{RECUR}', $val['recur'], $events_tmp);
+				}
+				
+					$search		= array('{EVENT_START}', '{EVENT_TEXT}', '{DESCRIPTION}','{LOCATION}');
+					$replace	= array($event_start, $event_text, $description, $location);
+				$events_tmp = str_replace($search, $replace, $events_tmp);
+				$some_events .= $events_tmp;
+				$events_tmp	= $loop_event;
+				
+			
+			$some_events  = str_replace('{KEY}', $val['date'], $some_events);
+			$some_events  = str_replace('{DAYOFMONTH}', $dayofmonth, $some_events);
+			$final   .= $day_tmp.$some_events;
+			unset ($day_tmp, $some_events);
+
+		}
+		}		
+		if ($events_found < 1) {
+			$this->page = preg_replace('!<\!-- switch results on -->(.*)<\!-- switch results off -->!is', '', $this->page);
+		} else {
+			$this->page = preg_replace('!<\!-- switch results on -->(.*)<\!-- switch results off -->!is', $final, $this->page);
+			$this->page = preg_replace('!<\!-- switch no_results on -->(.*)<\!-- switch no_results off -->!is', '', $this->page);
+			#echo "<hr>this->page: $this->page<br><hr>";
+
+		}
+	}#end draw_search
+	
 	function draw_week($template_p) {
 		global $unique_colors, $start_week_time, $template, $getdate, $cal, $master_array, $daysofweek_lang, $week_start_day, $dateFormat_week_list, $current_view, $day_array, $timeFormat, $gridLength, $timeFormat_small, $day_start;
 		
@@ -151,17 +265,15 @@ class Page {
 		$loop_ad 	= trim($match1[1]);
 		$loop_begin = trim($match2[1]);
 		$loop_end 	= trim($match3[1]);
-		foreach ($weekarray as $key => $get_date) {
+		foreach ($weekarray as $get_date) {
 			$replace 	= $loop_begin;
 			$colspan	= 'colspan="'.$nbrGridCols[$get_date].'"';
 			$replace 	= str_replace('{COLSPAN}', $colspan, $replace);
 			if (is_array($master_array[$get_date]['-1'])) {
-				foreach ($master_array[$get_date]['-1'] as $allday) {
+				foreach ($master_array[$get_date]['-1'] as $uid => $allday) {
 					$event_calno  	= $allday['calnumber'];
-					$event_calna  	= $allday['calname'];
-					$event_url	   	= $allday['url'];
-					if ($event_calno > $unique_colors) $event_calno = ($event_calno - $unique_colors);
-					$event 			= openevent($event_calna, '', '', $allday, 1, 11, '', '', 'psf', $event_url);
+					$event_calno	= (($event_calno - 1) % $unique_colors) + 1;
+ 					$event 			= openevent($get_date, -1, $uid, $allday, 1, 11, 'psf');
 					$loop_tmp 		= str_replace('{ALLDAY}', $event, $loop_ad);
 					$loop_tmp 		= str_replace('{CALNO}', $event_calno, $loop_tmp);
 					$replace		.= $loop_tmp;
@@ -252,27 +364,33 @@ class Page {
 				$thisday = date("Ymd", $thisdate);
 				$dayborder = 0;
 				unset($this_time_arr);
-				if (isset($master_array[$thisday][$cal_time]) && sizeof($master_array[$thisday][$cal_time]) > 0) {
-					$this_time_arr = $master_array[$thisday][$cal_time];
-				}
-					
+
 				if ($day_start == $cal_time && isset($master_array[$thisday]) && is_array($master_array[$thisday])) {
 					foreach($master_array[$thisday] as $time_key => $time_arr) {
-						if ((int)$time_key < (int)$cal_time && is_array($time_arr) && $time_key != '-1') {
-							foreach($time_arr as $event_tmp) {
-								if ((int)$event_tmp['event_end'] > (int)$cal_time) {
-									$this_time_arr[] = $event_tmp;
+						if ((int)$time_key <= (int)$cal_time) {
+							if (is_array($time_arr) && $time_key != '-1') {
+								foreach($time_arr as $uid => $event_tmp) {
+									if ((int)$event_tmp['event_end'] > (int)$cal_time) {
+										$this_time_arr[$uid] = $event_tmp;
+									}
 								}
 							}
 						} else {
 							break;
 						}
 					}
+				} else {
+					if (isset($master_array[$thisday][$cal_time]) && sizeof($master_array[$thisday][$cal_time]) > 0) {
+						$this_time_arr = $master_array[$thisday][$cal_time];
+					}
 				}
 				
-				
 				// check for eventstart 
 				if (isset($this_time_arr) && sizeof($this_time_arr) > 0) {
+					#print "<pre>";
+					#print_r ($this_time_arr);
+					#print "</pre>";
+
 					foreach ($this_time_arr as $eventKey => $loopevent) {
 						$drawEvent = drawEventTimes ($cal_time, $loopevent["event_end"]);
 						$j = 0;
@@ -304,33 +422,34 @@ class Page {
 					
 				} else {
 					$emptyWidth = $nbrGridCols[$thisday];
+					// Used to "join" ended events, so the ended case below results in one colspan'd td instead of multiple tds.
+					$ended_counter = 0;
 					for ($i=0;$i<sizeof($event_length[$thisday]);$i++) {
-					
+
 						$drawWidth = $nbrGridCols[$thisday] / ($event_length[$thisday][$i]["overlap"] + 1);
 						$emptyWidth = $emptyWidth - $drawWidth;
 						switch ($event_length[$thisday][$i]["state"]) {
 							case "begin":
+								if ($ended_counter) {
+									$weekdisplay .= '<td colspan="' . $ended_counter . '" '.$class.'>&nbsp;</td>';
+									$ended_counter = 0;
+								}
 								$event_length[$thisday][$i]["state"] = "started";
-								$event_start 	= $this_time_arr[($event_length[$thisday][$i]["key"])]['start_unixtime'];
+ 								$uid = $event_length[$thisday][$i]["key"];
+ 								$event_start 	= $this_time_arr[$uid]['start_unixtime'];
 								$event_start 	= date ($timeFormat_small, $event_start);
-								$event_calno  	= $this_time_arr[($event_length[$thisday][$i]['key'])]['calnumber'];
-								$event_calna  	= $this_time_arr[($event_length[$thisday][$i]['key'])]['calname'];
-								$event_url  	= $this_time_arr[($event_length[$thisday][$i]['key'])]['url'];
-								$event_status	= strtolower($this_time_arr[($event_length[$thisday][$i]['key'])]['status']);
-								if ($event_calno > $unique_colors) $event_calno = ($event_calno - $unique_colors);
+ 								$event_calno  	= $this_time_arr[$uid]['calnumber'];
+ 								$event_status	= strtolower($this_time_arr[$uid]['status']);
+								$event_calno = (($event_calno - 1) % $unique_colors) + 1;
 								if ($event_status != '') {
 						  			$confirmed = '<img src="images/'.$event_status.'.gif" width="9" height="9" alt="" border="0" hspace="0" vspace="0" />&nbsp;';
 						  		}
 								$colspan_width = round((80 / $nbrGridCols[$thisday]) * $drawWidth);
 								$weekdisplay .= '<td width="'.$colspan_width.'" rowspan="' . $event_length[$thisday][$i]['length'] . '" colspan="' . $drawWidth . '" align="left" valign="top" class="eventbg2_'.$event_calno.'">'."\n";
 
-								$event_end	= $this_time_arr[($event_length[$thisday][$i]["key"])]["end_unixtime"];
-								 if (isset($this_time_arr[($event_length[$thisday][$i]["key"])]['display_end'])) $event_end = strtotime ($this_time_arr[($event_length[$thisday][$i]["key"])]['display_end']);
-								$event_end 	= date ($timeFormat, $event_end);
-							  
 								// Start drawing the event
-								$event_temp  = $loop_event;
-								$event 		 = openevent($event_calna, $event_start, $event_end, $this_time_arr[($event_length[$thisday][$i]["key"])], $week_events_lines, 25, '', '', 'ps', $event_url);
+								$event_temp   = $loop_event;
+								$event 		  = openevent($thisday, $cal_time, $uid, $this_time_arr[$uid], $week_events_lines, 25, 'ps');
 								$event_temp   = str_replace('{EVENT}', $event, $event_temp);
 								$event_temp   = str_replace('{EVENT_START}', $event_start, $event_temp);
 								$event_temp   = str_replace('{CONFIRMED}', $confirmed, $event_temp);
@@ -338,12 +457,16 @@ class Page {
 								$weekdisplay .= $event_temp;
 								$weekdisplay .= '</td>';
 								// End event drawing
-						  
+
 								break;
 							case "started":
+								if ($ended_counter) {
+									$weekdisplay .= '<td colspan="' . $ended_counter . '" '.$class.'>&nbsp;</td>';
+									$ended_counter = 0;
+								}
 								break;
 							case "ended":
-								$weekdisplay .= '<td colspan="' . $drawWidth . '" '.$class.'>&nbsp;</td>';
+								$ended_counter += $drawWidth;
 								break;
 						}
 						$event_length[$thisday][$i]["length"]--;
@@ -351,7 +474,10 @@ class Page {
 							$event_length[$thisday][$i]["state"] = "ended";
 						}
 					}
-					//fill emtpy space on the right
+
+					// Clean up
+					$emptyWidth += $ended_counter;
+					//fill empty space on the right
 					if ($emptyWidth > 0) {
 						$weekdisplay .= "<td colspan=\"" . $emptyWidth . "\" $class>&nbsp;</td>\n";
 					}
@@ -363,39 +489,34 @@ class Page {
 			}
 			$weekdisplay .= "</tr>\n";
 		}
-		
+
 		$this->page = preg_replace('!<\!-- loop row on -->(.*)<\!-- loop event off -->!is', $weekdisplay, $this->page);
-		
-		
-		
 	}
-	
+
 	function draw_day($template_p) {
 		global $template, $getdate, $cal, $master_array, $unique_colors, $daysofweek_lang, $week_start_day, $dateFormat_week_list, $current_view, $day_array, $timeFormat, $gridLength, $day_start;
-		
+
 		// Replaces the allday events
 		$replace = '';
 		if (is_array($master_array[$getdate]['-1'])) {
 			preg_match("!<\!-- loop allday on -->(.*)<\!-- loop allday off -->!is", $this->page, $match1);
 			$loop_ad = trim($match1[1]);
-			foreach ($master_array[$getdate]['-1'] as $allday) {
+			foreach ($master_array[$getdate]['-1'] as $uid => $allday) {
 				$event_calno  	= $allday['calnumber'];
-				$event_calna  	= $allday['calname'];
-				$event_url	   	= $allday['url'];
-				if ($event_calno > $unique_colors) $event_calno = ($event_calno - $unique_colors);
-				$event 			= openevent($event_calna, '', '', $allday, 0, '', '', '', '', $event_url);
+				$event_calno	= (($event_calno - 1) % $unique_colors) + 1;
+ 				$event 			= openevent($getdate, -1, $uid, $allday);
 				$loop_tmp 		= str_replace('{ALLDAY}', $event, $loop_ad);
 				$loop_tmp 		= str_replace('{CALNO}', $event_calno, $loop_tmp);
 				$replace		.= $loop_tmp;
 			}
 		}
 		$this->page = preg_replace('!<\!-- loop allday on -->(.*)<\!-- loop allday off -->!is', $replace, $this->page);
-	
+
 		// Replaces the daysofweek
 		preg_match("!<\!-- loop daysofweek on -->(.*)<\!-- loop daysofweek off -->!is", $this->page, $match1);
 		$loop_dof = trim($match1[1]);
 		$start_wt		 	= strtotime(dateOfWeek($getdate, $week_start_day));
-		$start_day 			= strtotime($week_start_day);
+		$start_day 			= strtotime(dateOfWeek($getdate, $week_start_day));
 		for ($i=0; $i<7; $i++) {
 			$day_num 		= date("w", $start_day);
 			$daylink		= date('Ymd', $start_wt);
@@ -453,26 +574,28 @@ class Page {
 			$key = date ($timeFormat, $key);
 			unset($this_time_arr);
 			
-			// add events that overlap the start time
-			if (isset($master_array[$getdate][$cal_time]) && sizeof($master_array[$getdate][$cal_time]) > 0) {
-				$this_time_arr = $master_array[$getdate][$cal_time];
-			}
-			
 			// add events that overlap $day_start instead of cutting them out completely
 			if (($day_start == $cal_time) && (isset($master_array[$getdate]))) {
 				foreach($master_array[$getdate] as $time_key => $time_arr) {
-					if ((int)$time_key < (int)$cal_time && is_array($time_arr) && $time_key != '-1') {
-						foreach($time_arr as $event_tmp) {
-							if ((int)$event_tmp['event_end'] > (int)$cal_time) {
-								$this_time_arr[] = $event_tmp;
+					if ((int)$time_key <= (int)$cal_time) {
+						if (is_array($time_arr) && $time_key != '-1') {
+							foreach($time_arr as $uid => $event_tmp) {
+								if ((int)$event_tmp['event_end'] > (int)$cal_time) {
+									$this_time_arr[$uid] = $event_tmp;
+								}
 							}
 						}
 					} else {
 						break;
 					}
 				}
-			}																		
-			
+			} else {
+				// add events that overlap the start time
+				if (isset($master_array[$getdate][$cal_time]) && sizeof($master_array[$getdate][$cal_time]) > 0) {
+					$this_time_arr = $master_array[$getdate][$cal_time];
+				}
+			}
+
 			// check for eventstart 
 			if (isset($this_time_arr) && sizeof($this_time_arr) > 0) {
 				foreach ($this_time_arr as $eventKey => $loopevent) {
@@ -515,21 +638,28 @@ class Page {
 				
 			} else {
 				$emptyWidth = $nbrGridCols;
+				// Used to "join" ended events, so the ended case below results in one colspan'd td instead of multiple tds.
+				$ended_counter = 0;
 				for ($i=0;$i<sizeof($event_length);$i++) {
 					$drawWidth = $nbrGridCols / ($event_length[$i]['overlap'] + 1);
 					$emptyWidth = $emptyWidth - $drawWidth;
 					switch ($event_length[$i]['state']) {
 						case 'begin':
+						  if ($ended_counter) {
+							$daydisplay .= '<td colspan="' . $ended_counter . '" '.$class.'>&nbsp;</td>';
+							$ended_counter = 0;
+						  }
 						  $event_length[$i]['state'] = 'started';
-						  $event_start 	= strtotime ($this_time_arr[($event_length[$i]['key'])]['event_start']);
-						  $event_end	= strtotime ($this_time_arr[($event_length[$i]['key'])]['event_end']);
-						  if (isset($this_time_arr[($event_length[$i]['key'])]['display_end'])) $event_end = strtotime ($this_time_arr[($event_length[$i]['key'])]['display_end']);
+ 						  $uid = $event_length[$i]['key'];
+ 						  $event_start 	= strtotime ($this_time_arr[$uid]['event_start']);
+ 						  $event_end	= strtotime ($this_time_arr[$uid]['event_end']);
+ 						  if (isset($this_time_arr[$uid]['display_end'])) $event_end = strtotime ($this_time_arr[$uid]['display_end']);
 						  $event_start 	= date ($timeFormat, $event_start);
 						  $event_end	= date ($timeFormat, $event_end);
-						  $event_calno  = $this_time_arr[($event_length[$i]['key'])]['calnumber'];
-						  $event_recur  = $this_time_arr[($event_length[$i]['key'])]['recur'];
-						  $event_status = strtolower($this_time_arr[($event_length[$i]['key'])]['status']);
-						  if ($event_calno > $unique_colors) $event_calno = ($event_calno - $unique_colors);
+ 						  $event_calno  = $this_time_arr[$uid]['calnumber'];
+ 						  $event_recur  = $this_time_arr[$uid]['recur'];
+ 						  $event_status = strtolower($this_time_arr[$uid]['status']);
+						  $event_calno  = (($event_calno - 1) % $unique_colors) + 1;
 						  if ($event_status != '') {
 						  	$confirmed = '<img src="images/'.$event_status.'.gif" width="9" height="9" alt="" border="0" hspace="0" vspace="0" />&nbsp;';
 						  } elseif (is_array($event_recur)) {
@@ -540,20 +670,22 @@ class Page {
 						  
 						  // Start drawing the event
 						  $event_temp  = $loop_event;
-						  $event_calna = $this_time_arr[($event_length[$i]['key'])]['calname'];
-						  $event_url   = $this_time_arr[($event_length[$i]['key'])]['url'];
-						  $event 	   = openevent($event_calna, $event_start, $event_end, $this_time_arr[($event_length[$i]['key'])], '', 0, '', '', 'ps', $event_url);
-						  $event_temp   = str_replace('{EVENT}', $event, $event_temp);
-						  $event_temp   = str_replace('{EVENT_START}', $event_start, $event_temp);
-						  $event_temp   = str_replace('{EVENT_END}', $event_end, $event_temp);
-						  $event_temp   = str_replace('{CONFIRMED}', $confirmed, $event_temp);
-						  $event_temp   = str_replace('{EVENT_CALNO}', $event_calno, $event_temp);
+						  $event 	   = openevent($getdate, $cal_time, $uid, $this_time_arr[$uid], 0, 0, 'ps');
+						  $event_temp  = str_replace('{EVENT}', $event, $event_temp);
+						  $event_temp  = str_replace('{EVENT_START}', $event_start, $event_temp);
+						  $event_temp  = str_replace('{EVENT_END}', $event_end, $event_temp);
+						  $event_temp  = str_replace('{CONFIRMED}', $confirmed, $event_temp);
+						  $event_temp  = str_replace('{EVENT_CALNO}', $event_calno, $event_temp);
 						  $daydisplay .= $event_temp;
 						  $daydisplay .= '</td>';
 						  // End event drawing
 						  
 						  break;
 						case 'started':
+							if ($ended_counter) {
+								$daydisplay .= '<td colspan="' . $ended_counter . '" '.$class.'>&nbsp;</td>';
+								$ended_counter = 0;
+							}
 							break;
 						case 'ended':
 							$daydisplay .= '<td colspan="' . $drawWidth . '" ' . $class . '>&nbsp;</td>'."\n";
@@ -564,7 +696,10 @@ class Page {
 						$event_length[$i]['state'] = 'ended';
 					}
 				}
-				//fill emtpy space on the right
+
+				// Clean up.
+				$emptyWidth += $ended_counter;
+				//fill empty space on the right
 				if ($emptyWidth > 0) {
 					$daydisplay .= '<td colspan="' . $emptyWidth . '" ' . $class . '>&nbsp;</td>'."\n";
 				}
@@ -590,44 +725,36 @@ class Page {
 		$loop_t_e 	= trim($match2[1]);
 		$return_adtmp	= '';
 		$return_etmp	= '';
-		
+
 		if (is_array($master_array[$next_day]) && sizeof($master_array[$next_day]) > 0) {
-			foreach ($master_array[$next_day] as $event_times) {
-				foreach ($event_times as $val) {
+			foreach ($master_array[$next_day] as $cal_time => $event_times) {
+				foreach ($event_times as $uid => $val) {
 					$event_text = stripslashes(urldecode($val["event_text"]));
 					$event_text = strip_tags($event_text, '<b><i><u>');
-					if ($event_text != "") {	
-						$event_start 	= $val["event_start"];
-						$event_end 		= $val["event_end"];
-						$event_calna 	= $val["calname"];
-						$event_url 		= $val["url"];
-						$event_start 	= date ($timeFormat, @strtotime ($event_start));
-						$event_end 		= date ($timeFormat, @strtotime ($event_end));
-						if (!isset($val["event_start"])) { 
-							$event_start = $lang['l_all_day']; 
-							$event_end = ''; 
-							$return_adtmp = openevent($event_calna, $event_start, $event_end, $val, $tomorrows_events_lines, 21, '', '', 'psf', $event_url); 
-							$replace_ad 	.= str_replace('{T_ALLDAY}', $return_adtmp, $loop_t_ad);
-						} else { 
-							$return_etmp 	= openevent($event_calna, $event_start, $event_end, $val, $tomorrows_events_lines, 21, '', '', 'ps3', $event_url); 
-							$replace_e 		.= str_replace('{T_EVENT}', $return_etmp, $loop_t_e);
+					if ($event_text != "") {
+						if (!isset($val["event_start"])) {
+							$return_adtmp = openevent($next_day, $cal_time, $uid, $val, $tomorrows_events_lines, 21, 'psf');
+							$replace_ad  .= str_replace('{T_ALLDAY}', $return_adtmp, $loop_t_ad);
+						} else {
+							$return_etmp  = openevent($next_day, $cal_time, $uid, $val, $tomorrows_events_lines, 21, 'ps3');
+							$replace_e   .= str_replace('{T_EVENT}', $return_etmp, $loop_t_e);
 						}
 					}
 				}
 			}
-		
+
 			$this->page = preg_replace('!<\!-- switch t_allday on -->(.*)<\!-- switch t_allday off -->!is', $replace_ad, $this->page);
 			$this->page = preg_replace('!<\!-- switch t_event on -->(.*)<\!-- switch t_event off -->!is', $replace_e, $this->page);		
-	
+
 		} else {
-		
+
 			$this->page = preg_replace('!<\!-- switch tomorrows_events on -->(.*)<\!-- switch tomorrows_events off -->!is', '', $this->page);
-		
+
 		}
 	}
-	
+
 	function get_vtodo() {
-		global $template, $getdate, $master_array, $next_day, $timeFormat, $tomorrows_events_lines, $show_completed;
+		global $template, $getdate, $master_array, $next_day, $timeFormat, $tomorrows_events_lines, $show_completed, $show_todos;
 		
 		preg_match("!<\!-- switch show_completed on -->(.*)<\!-- switch show_completed off -->!is", $this->page, $match1);
 		preg_match("!<\!-- switch show_important on -->(.*)<\!-- switch show_important off -->!is", $this->page, $match2);
@@ -643,7 +770,7 @@ class Page {
 					$vtodo_text = stripslashes(urldecode($val["vtodo_text"]));
 					if ($vtodo_text != "") {	
 						if (isset($val["description"])) { 
-							$description 	= urldecode($val["description"]);
+							$description 	= stripslashes(urldecode($val["description"]));
 						} else {
 							$description = ""; 
 						}
@@ -692,7 +819,7 @@ class Page {
 		}
 		
 		// If there are no TODO items, completely hide the TODO list.
-		if ($nugget2 == '') {
+		if (($nugget2 == '') || ($show_todos != 'yes')) {
 			$this->page = preg_replace('!<\!-- switch vtodo on -->(.*)<\!-- switch vtodo off -->!is', '', $this->page);
 		}
 		
@@ -726,7 +853,17 @@ class Page {
 			$fake_getdate_time 	= strtotime($this_year.'-'.$offset.'-15');
 		}
 		
-		$start_day 			= strtotime($week_start_day);
+		$minical_month 		= date("m", $fake_getdate_time);
+		$minical_year 		= date("Y", $fake_getdate_time);
+		$first_of_month 	= $minical_year.$minical_month."01";
+		$first_of_year 		= $minical_year."0101";
+
+		// Add links in to the month/year views.
+		$dateFormat_month = str_replace("%B", "<a class=\"ps3\" href=\"month.php?cal=$cal&amp;getdate=$first_of_month\">%B</a>", $dateFormat_month);
+		$dateFormat_month = str_replace("%Y", "<a class=\"ps3\" href=\"year.php?cal=$cal&amp;getdate=$first_of_year\">%Y</a>", $dateFormat_month);
+
+		//$start_day 			= strtotime($week_start_day);
+		$start_day			= strtotime(dateOfWeek($getdate, $week_start_day));
 		$month_title 		= localizeDate ($dateFormat_month, $fake_getdate_time);
 		$month_date 		= date ('Ymd', $fake_getdate_time);
 
@@ -746,9 +883,6 @@ class Page {
 			$weekday_loop  .= $loop_tmp;
 		}
 		
-		$minical_month 		= date("m", $fake_getdate_time);
-		$minical_year 		= date("Y", $fake_getdate_time);
-		$first_of_month 	= $minical_year.$minical_month."01";
 		$start_day 			= strtotime(dateOfWeek($first_of_month, $week_start_day));
 		$i 					= 0;
 		$whole_month 		= TRUE;
@@ -770,29 +904,23 @@ class Page {
 			}
 			if ($master_array[$daylink]) {
 				if ($type != 'small') {
-					foreach ($master_array[$daylink] as $event_times) {
-						foreach ($event_times as $val) {
+					foreach ($master_array[$daylink] as $cal_time => $event_times) {
+						foreach ($event_times as $uid => $val) {
 							$event_calno 	= $val['calnumber'];
-							if ($event_calno > $unique_colors) $event_calno = ($event_calno - $unique_colors);
-							$event_calna 	= $val['calname'];
-							$event_url 		= $val['url'];
+							$event_calno	= (($event_calno - 1) % $unique_colors) + 1;
 							if (!isset($val['event_start'])) {
 								if ($type == 'large') {
 									$switch['ALLDAY'] .= '<div class="V10"><img src="templates/'.$template.'/images/monthdot_'.$event_calno.'.gif" alt="" width="9" height="9" border="0" />';
-									$switch['ALLDAY'] .= openevent($event_calna, '', '', $val, $month_event_lines, 15, '', '', 'psf', $event_url);
+ 									$switch['ALLDAY'] .= openevent($daylink, $cal_time, $uid, $val, $month_event_lines, 15, 'psf');
 									$switch['ALLDAY'] .= '</div>';
 								} else {
 									$switch['ALLDAY'] .= '<img src="templates/'.$template.'/images/allday_dot.gif" alt=" " width="11" height="10" border="0" />';
 								}
 							} else {	
-								$event_start = $val['start_unixtime'];
-								$event_end 	 = (isset($val['display_end'])) ? $val['display_end'] : $val["event_end"];
-								$event_start = date($timeFormat, $val['start_unixtime']);
 								$start2		 = date($timeFormat_small, $val['start_unixtime']);
-								$event_end   = date($timeFormat, @strtotime ($event_end));
 								if ($type == 'large') {
 									$switch['EVENT'] .= '<div class="V9"><img src="templates/'.$template.'/images/monthdot_'.$event_calno.'.gif" alt="" width="9" height="9" border="0" />';
-									$switch['EVENT'] .= openevent($event_calna, $event_start, $event_end, $val, $month_event_lines, 10, "$start2 ", '', 'ps3', $event_url).'<br />';
+ 									$switch['EVENT'] .= openevent($daylink, $cal_time, $uid, $val, $month_event_lines, 10, 'ps3', "$start2 ").'<br />';
 									$switch['EVENT'] .= '</div>';
 								} else {
 									$switch['EVENT'] = '<img src="templates/'.$template.'/images/event_dot.gif" alt=" " width="11" height="10" border="0" />';
@@ -831,6 +959,14 @@ class Page {
 		return $return;	
 	}
 	
+	function nomonthbottom() {
+		$this->page = preg_replace('!<\!-- switch showbottom on -->(.*)<\!-- switch showbottom off -->!is','', $this->page);
+	}
+
+	function nosearch() {
+		$this->page = preg_replace('!<\!-- switch show_search on -->(.*)<\!-- switch show_search off -->!is','', $this->page);
+	}
+	
 	function monthbottom() {
 		global $template, $getdate, $master_array, $this_year, $this_month, $cal, $timeFormat, $timeFormat_small, $dateFormat_week_list, $lang;
 		preg_match("!<\!-- loop showbottomevents_odd on -->(.*)<\!-- loop showbottomevents_odd off -->!is", $this->page, $match1);
@@ -844,25 +980,25 @@ class Page {
 		$i=0;
 		do {
 			if (isset($master_array[$m_start])) {
-				foreach ($master_array[$m_start] as $event_times) {
+				foreach ($master_array[$m_start] as $cal_time => $event_times) {
 					$switch['CAL'] 			= $cal;
 					$switch['START_DATE'] 	= localizeDate ($dateFormat_week_list, $u_start);
-					foreach ($event_times as $val) {
+					foreach ($event_times as $uid => $val) {
 						$switch['CALNAME'] 	= $val['calname'];
-						$switch['URL'] 		= $val['url'];
 						if (!isset($val['event_start'])) {
 							$switch['START_TIME'] 	= $lang['l_all_day'];
+							$switch['EVENT_TEXT'] 	= openevent($m_start, $cal_time, $uid, $val, $month_event_lines, 15, 'psf');
 							$switch['DESCRIPTION'] 	= urldecode($val['description']);
-							$switch['EVENT_TEXT'] 	= openevent($switch['CALNAME'], '', '', $val, $month_event_lines, 15, '', '', 'psf', $switch['URL']);
-						} else {	
+						} else {
 							$event_start = $val['start_unixtime'];
 							$event_end 	 = (isset($val['display_end'])) ? $val['display_end'] : $val["event_end"];
 							$event_start = date($timeFormat, $val['start_unixtime']);
 							$event_end   = date($timeFormat, @strtotime ($event_end));
 							$switch['START_TIME'] 	= $event_start . ' - ' . $event_end;
-							$switch['EVENT_TEXT'] 	= openevent($switch['CALNAME'], $event_start, $event_end, $val, 0, 15, '', '', 'psf', $switch['URL']);
+							$switch['EVENT_TEXT'] 	= openevent($m_start, $cal_time, $uid, $val, 0, 15, 'psf');
 							$switch['DESCRIPTION'] 	= urldecode($val['description']);
 						}
+
 						if ($switch['EVENT_TEXT'] != '') {
 							$switch['DAYLINK'] = $m_start;
 							$temp = $loop[$i];
@@ -880,11 +1016,11 @@ class Page {
 			$check_month = date('m', $u_start);
 			unset ($switch);
 		} while ($this_month == $check_month);
-		
+
 		$this->page = preg_replace('!<\!-- loop showbottomevents_odd on -->(.*)<\!-- loop showbottomevents_even off -->!is', $middle, $this->page);
-			
+
 	}
-	
+
 	function Page($template = 'std.tpl') {
 		if (file_exists($template))
 			$this->page = join('', file($template));
@@ -938,7 +1074,7 @@ class Page {
 		}
 	
 	function output() {
-		global $template, $php_started, $lang, $enable_rss, $template_started;
+		global $template, $php_started, $lang, $enable_rss, $template_started, $cpath;
 		
 		// Looks for {MONTH} before sending page out
 		preg_match_all ('!\{MONTH_([A-Z]*)\|?([+|-])([0-9]{1,2})\}!is', $this->page, $match);
@@ -974,6 +1110,9 @@ class Page {
 		} else {
 			$this->page = str_replace('{BASE}', BASE, $this->page);
 		}
+		if ($cpath){
+			$this->page = str_replace('&amp;getdate', "&amp;cpath=$cpath&amp;getdate", $this->page);
+		}
 		print($this->page);
 	}
 }
