@@ -7,12 +7,16 @@ if (isset($_COOKIE['phpicalendar'])) {
 	$default_view 		= $phpicalendar['cookie_view'];
 }
 if ($printview_default == 'yes') {
-	$default_view = "print.php?printview=$default_view";
+	$printview = $default_view;
+	$default_view = "print.php";
 } else {
-	$default_view = "$default_view" . ".php";
+	$check = array ('day', 'week', 'month');
+	if (in_array($default_view, $check)) {
+		$default_view = $default_view . '.php';
+	} else {
+		die;
+	}
 }
-/*header("Location: $default_view");*/
+header("Location: $default_view");
 
-include( $default_view );
-
-?>
\ No newline at end of file
+?>
