@@ -11,81 +11,81 @@
 $lang['l_day'] 				= 'Jour';
 $lang['l_week'] 			= 'Semaine';
 $lang['l_month'] 			= 'Mois';
-$lang['l_year'] 			= 'Anne';
+$lang['l_year'] 			= 'Ann&eacute;e';
 $lang['l_calendar'] 		= 'Calendrier';
 $lang['l_next_day'] 		= 'Jour suivant';
 $lang['l_next_month'] 		= 'Mois suivant';
 $lang['l_next_week'] 		= 'Semaine suivante';
-$lang['l_next_year'] 		= 'Anne suivante';
-$lang['l_last_day'] 		= 'Jour prcdent';
-$lang['l_last_month'] 		= 'Mois prcdent';
-$lang['l_last_week'] 		= 'Semaine prcdente';
-$lang['l_last_year'] 		= 'Anne prcdente';
+$lang['l_next_year'] 		= 'Ann&eacute;e suivante';
+$lang['l_last_day'] 		= 'Jour pr&eacute;c&eacute;dent';
+$lang['l_last_month'] 		= 'Mois pr&eacute;c&eacute;dent';
+$lang['l_last_week'] 		= 'Semaine pr&eacute;c&eacute;dente';
+$lang['l_last_year'] 		= 'Ann&eacute;e pr&eacute;c&eacute;dente';
 $lang['l_subscribe'] 		= 'Souscrire';
-$lang['l_download'] 		= 'Tlcharger';
+$lang['l_download'] 		= 'T&eacute;l&eacute;charger';
 $lang['l_powered_by'] 		= 'Produit avec';
-$lang['l_event'] 			= 'Evnement';
-$lang['l_event_start'] 		= 'Dbut';
+$lang['l_event'] 			= 'Ev&eacute;nement';
+$lang['l_event_start'] 		= 'D&eacute;but';
 $lang['l_event_end'] 		= 'Fin';
-$lang['l_this_months'] 		= 'Evnements de ce mois';
+$lang['l_this_months'] 		= 'Ev&eacute;nements de ce mois';
 $lang['l_date'] 			= 'Date';
-$lang['l_summary'] 			= 'Rsum';
-$lang['l_all_day'] 			= 'Evnements de ce jour';
+$lang['l_summary'] 			= 'R&eacute;sum&eacute;';
+$lang['l_all_day'] 			= 'Ev&eacute;nements de ce jour';
 $lang['l_notes'] 			= 'Notes';
-$lang['l_this_years'] 		= 'Evnements de cette anne';
+$lang['l_this_years'] 		= 'Ev&eacute;nements de cette ann&eacute;e';
 $lang['l_today'] 			= 'Aujourd\'hui';
 $lang['l_this_week'] 		= 'Cette semaine';
 $lang['l_this_month'] 		= 'Ce mois';
 $lang['l_jump'] 			= 'Voir';
-$lang['l_tomorrows'] 		= 'Evnement de demain';
+$lang['l_tomorrows'] 		= 'Ev&eacute;nement de demain';
 $lang['l_goday'] 			= 'Voir aujourd\'hui';
 $lang['l_goweek'] 			= 'Voir cette semaine';
 $lang['l_gomonth'] 			= 'Voir ce mois';
-$lang['l_goyear'] 			= 'Voir cette anne';
+$lang['l_goyear'] 			= 'Voir cette ann&eacute;e';
 $lang['l_search'] 			= 'Rechercher'; // the verb
-$lang['l_results'] 			= 'Rsultats de la recherche';
-$lang['l_query'] 			= 'Requte'; // will be followed by the search query
-$lang['l_no_results'] 		= 'Aucun vnement trouv';
+$lang['l_results'] 			= 'R&eacute;sultats de la recherche';
+$lang['l_query'] 			= 'Requ&egrave;te'; // will be followed by the search query
+$lang['l_no_results'] 		= 'Aucun &eacute;v&eacute;nement trouv&eacute;';
 $lang['l_goprint'] 			= 'Version imprimable';
 $lang['l_time'] 			= 'Heure';
-$lang['l_summary'] 			= 'Rsum';
+$lang['l_summary'] 			= 'R&eacute;sum&eacute;';
 $lang['l_description'] 		= 'Description';
 $lang['l_this_site_is']		= 'Ce site est';
-$lang['l_no_events_day']	= 'Pas d\'vnements aujourd\'hui.';
-$lang['l_no_events_week']	= 'Pas d\'vnements cette semaine.';
-$lang['l_no_events_month']	= 'Pas d\'vnements ce mois.';
+$lang['l_no_events_day']	= 'Pas d\'&eacute;v&eacute;nements aujourd\'hui.';
+$lang['l_no_events_week']	= 'Pas d\'&eacute;v&eacute;nements cette semaine.';
+$lang['l_no_events_month']	= 'Pas d\'&eacute;v&eacute;nements ce mois.';
 $lang['l_rss_day_date']		= 'H:i';  // Lists just the time
 $lang['l_rss_week_date	']	= '%e %b';  // Lists just the day
 $lang['l_rss_month_date	']	= '%e %b';  // Lists just the day
 $lang['l_rss_language']		= 'fr-fr';
 $lang['l_search_took']		= 'La recherche a pris %s seconds';
-$lang['l_recurring_event']	= 'Evnement rcurent';
+$lang['l_recurring_event']	= 'Ev&eacute;nement r&eacute;curent';
 $lang['l_exception']		= 'Exception';
-$lang['l_no_query']			= 'Aucune requte';
-$lang['l_preferences']		= 'Prfrences';
+$lang['l_no_query']			= 'Aucune requ&egrave;te';
+$lang['l_preferences']		= 'Pr&eacute;f&eacute;rences';
 $lang['l_printer']			= 'Imprimante';
-$lang['l_select_lang']		= 'Choisissez votre langage par dfaut';
-$lang['l_select_cal']		= 'Choisissez votre calendrier par dfaut';
-$lang['l_select_view']		= 'Choisissez votre vue par dfaut';
-$lang['l_select_time']		= 'Choisissez votre heure de dbut par dfaut';
-$lang['l_select_day']		= 'Choisissez votre jour de dbut de semaine par dfaut';
-$lang['l_select_style']		= 'Choisissez votre style par dfaut';
-$lang['l_set_prefs']		= 'Enregistrer les prfrences';
-$lang['l_completed_date']	= 'Termin le';
-$lang['l_completed']		= 'Termin';
-$lang['l_created']			= 'Cr';
+$lang['l_select_lang']		= 'Choisissez votre langage par d&eacute;faut';
+$lang['l_select_cal']		= 'Choisissez votre calendrier par d&eacute;faut';
+$lang['l_select_view']		= 'Choisissez votre vue par d&eacute;faut';
+$lang['l_select_time']		= 'Choisissez votre heure de d&eacute;but par d&eacute;faut';
+$lang['l_select_day']		= 'Choisissez votre jour de d&eacute;but de semaine par d&eacute;faut';
+$lang['l_select_style']		= 'Choisissez votre style par d&eacute;faut';
+$lang['l_set_prefs']		= 'Enregistrer les pr&eacute;f&eacute;rences';
+$lang['l_completed_date']	= 'Termin&eacute; le';
+$lang['l_completed']		= 'Termin&eacute;';
+$lang['l_created']			= 'Cr&eacute;&eacute;';
 $lang['l_due']				= 'Fin:';
-$lang['l_priority']			= 'Priorit';
+$lang['l_priority']			= 'Priorit&eacute;';
 $lang['l_priority_high']	= 'Haute';
 $lang['l_priority_low']		= 'Basse';
 $lang['l_priority_medium']	= 'Moyenne';
 $lang['l_priority_none']	= 'Aucune';
 $lang['l_status']			= 'Status:';
-$lang['l_todo']				= 'Tches  raliser';
+$lang['l_todo']				= 'T&acirc;ches &agrave; r&eacute;aliser';
 $lang['l_unfinished']		= 'Non faites';
-$lang['l_prefs_set'] 		= 'Vos prfrences ont t modifies.';
-$lang['l_prefs_unset'] 		= 'Prfrences supprimes. Changement au prochain chargement de la page.';
-$lang['l_unset_prefs'] 		= 'Supprimez les prfrences';
+$lang['l_prefs_set'] 		= 'Vos pr&eacute;f&eacute;rences ont &eacute;t&eacute; modifi&eacute;es.';
+$lang['l_prefs_unset'] 		= 'Pr&eacute;f&eacute;rences supprim&eacute;es. Changement au prochain chargement de la page.';
+$lang['l_unset_prefs'] 		= 'Supprimez les pr&eacute;f&eacute;rences';
 $lang['l_organizer']		= 'Organizer';
 $lang['l_attendee']			= 'Attendee';
 $lang['l_status']			= 'Status';
@@ -94,31 +94,31 @@ $lang['l_admin_header']		= 'Administration de PHP iCalendar';
 $lang['l_username']			= 'Utilisateur';
 $lang['l_password']			= 'Mot de passe';
 $lang['l_login']			= 'Authentification';
-$lang['l_invalid_login']	= 'Utilisateur ou mot de passe erron.';
+$lang['l_invalid_login']	= 'Utilisateur ou mot de passe erron&eacute;.';
 $lang['l_addupdate_cal']	= 'Ajoutez ou modifiez un calendrier';
-$lang['l_addupdate_desc']	= 'Ajoutez un calendrier en chargeant un nouveau fichier. Modifiez un calendrier en chargeant un fichier de mme nom.';
+$lang['l_addupdate_desc']	= 'Ajoutez un calendrier en chargeant un nouveau fichier. Modifiez un calendrier en chargeant un fichier de m&ecirc;me nom.';
 $lang['l_delete_cal']		= 'Effacez un calendrier';
 $lang['l_logout']			= 'Logout';
 $lang['l_cal_file']			= 'Fichier calendrier';
 $lang['l_php_error']		= 'Erreur PHP';
-$upload_error_gen_lang		= 'Une erreur lors du tlchargement s\'est produite.';
-$upload_error_lang[0]		= 'Une erreur lors du tlchargement s\'est produite.';
-$upload_error_lang[1]		= 'Le fichier que vous tentez de tlcharger est trop grand.';
-$upload_error_lang[2]		= 'Le fichier que vous tentez de tlcharger est trop grand.';
-$upload_error_lang[3]		= 'Le fichier n\'a t que partiellement tlcharg.';
-$upload_error_lang[4]		= 'Vous devez choisir un fichier  tlcharger.';
-$lang['l_upload_error_type'] = 'Seuls des fichiers au format .ics peuvent tre tlchargs.';
-$lang['l_copy_error']			= 'La copie du fichier a chou';
-$lang['l_delete_error']			= 'La suppression du fichier a chou';
-$lang['l_delete_success']		= 'a t supprim avec succs.';
-$lang['l_action_success']		= 'Action effectue avec succs.';
+$upload_error_gen_lang		= 'Une erreur lors du t&eacute;l&eacute;chargement s\'est produite.';
+$upload_error_lang[0]		= 'Une erreur lors du t&eacute;l&eacute;chargement s\'est produite.';
+$upload_error_lang[1]		= 'Le fichier que vous tentez de t&eacute;l&eacute;charger est trop grand.';
+$upload_error_lang[2]		= 'Le fichier que vous tentez de t&eacute;l&eacute;charger est trop grand.';
+$upload_error_lang[3]		= 'Le fichier n\'a &eacute;t&eacute; que partiellement t&eacute;l&eacute;charg&eacute;.';
+$upload_error_lang[4]		= 'Vous devez choisir un fichier &agrave; t&eacute;l&eacute;charger.';
+$lang['l_upload_error_type'] = 'Seuls des fichiers au format .ics peuvent &ecirc;tre t&eacute;l&eacute;charg&eacute;s.';
+$lang['l_copy_error']			= 'La copie du fichier a &eacute;chou&eacute;';
+$lang['l_delete_error']			= 'La suppression du fichier a &eacute;chou&eacute;';
+$lang['l_delete_success']		= 'a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s.';
+$lang['l_action_success']		= 'Action effectu&eacute;e avec succ&egrave;s.';
 $lang['l_submit']				= 'Envoyer';
 $lang['l_delete']				= 'Supprimer';
 $all_cal_comb_lang			= 'Tous les calendriers';
 
 // New for 2.0
-$lang['l_legend']			= 'Lgende';
-$lang['l_admin_subhead']	= 'Contrlez vos calendriers  partir de cette page';
+$lang['l_legend']			= 'L&eacute;gende';
+$lang['l_admin_subhead']	= 'Contr&ocirc;lez vos calendriers &agrave; partir de cette page';
 $lang['l_prefs_subhead']	= 'Stock un cookie pour la visite de ce site';
 $lang['l_rss_info']			= 'Information RSS';
 $lang['l_rss_subhead']		= 'RSS feeds basic disponible pour chaque calendrier';
@@ -127,8 +127,8 @@ $lang['l_rss_notenabled']	= 'RSS n\'est pas disponible sur ce site';
 // - navigation
 $lang['l_back'] 		= 'Retour';
 $lang['l_next'] 		= 'Suivant';
-$lang['l_prev'] 		= 'Prcdent';
-$lang['l_day_view'] 	= 'Vue Journalire';
+$lang['l_prev'] 		= 'Pr&eacute;c&eacute;dent';
+$lang['l_day_view'] 	= 'Vue Journali&egrave;re';
 $lang['l_week_view'] 	= 'Vue Hebdomadaire';
 $lang['l_month_view'] 	= 'Vue Mensuelle';
 $lang['l_year_view'] 	= 'Vue annuelle';
@@ -160,8 +160,8 @@ $format_recur_lang['byday']			= 'Aux jours: %list%';			// ie, 'On days: Mon, Tue
 $daysofweek_lang			= array ('Dimanche','Lundi','Mardi','Mercredi','Jeudi','Vendredi','Samedi');
 $daysofweekshort_lang		= array ('Dim','Lun','Mar','Mer','Jeu','Ven','Sam');
 $daysofweekreallyshort_lang	= array ('D','L','M','M','J','V','S');
-$monthsofyear_lang			= array ('Janvier','Fvrier','Mars','Avril','Mai','Juin','Juillet','Aot','Septembre','Octobre','Novembre','Dcembre');
-$monthsofyearshort_lang		= array ('Jan','Fv','Mar','Avr','Mai','Juin','Juil','Aot','Sep','Oct','Nov','Dc');
+$monthsofyear_lang			= array ('Janvier','F&eacute;vrier','Mars','Avril','Mai','Juin','Juillet','Ao&ucirc;t','Septembre','Octobre','Novembre','D&eacute;cembre');
+$monthsofyearshort_lang		= array ('Jan','F&eacute;v','Mar','Avr','Mai','Juin','Juil','Ao&ucirc;t','Sep','Oct','Nov','D&eacute;c');
 
 // For time formatting, check out: http://www.php.net/manual/en/function.date.php
 $timeFormat = 'H:i';
@@ -196,10 +196,10 @@ $lang['l_error_title'] 			= 'Erreur!';
 $lang['l_error_window'] 		= 'Une erreur s\'est produite!';
 $lang['l_error_calendar'] 		= 'Une erreur s\'est produite lors du traitement du calendrier "%s".';
 $lang['l_error_path'] 			= 'Impossible d\'ouvrir le chemin: "%s"';
-$lang['l_error_back'] 			= 'Veuillez utiliser le bouton "Retour" pour revenir en arrire.';
-$lang['l_error_remotecal'] 		= 'Ce serveur refuse les calendriers distants non approuvs.';
-$lang['l_error_restrictedcal'] 	= 'Vous avez essay d\'utiliser un calendrier dont les permissions sont restreintes sur ce serveur.';
-$lang['l_error_invalidcal'] 	= 'Fichier calendrier invalide. Veuillez essayer un calendrier diffrent.';
+$lang['l_error_back'] 			= 'Veuillez utiliser le bouton "Retour" pour revenir en arri&egrave;re.';
+$lang['l_error_remotecal'] 		= 'Ce serveur refuse les calendriers distants non approuv&eacute;s.';
+$lang['l_error_restrictedcal'] 	= 'Vous avez essay&eacute; d\'utiliser un calendrier dont les permissions sont restreintes sur ce serveur.';
+$lang['l_error_invalidcal'] 	= 'Fichier calendrier invalide. Veuillez essayer un calendrier diff&eacute;rent.';
 $lang['l_error_cantopen'] 		= 'Unable to open calendar.';
 $lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';
 
