@@ -80,7 +80,7 @@ $lang['l_priority_high']	= '高い';
 $lang['l_priority_low']		= '低い';
 $lang['l_priority_medium']	= '普通';
 $lang['l_priority_none']	= 'なし';
-$lang['l_status']			= '状態:';
+$lang['l_status']			= '状態';
 $lang['l_todo']				= '備忘録';
 $lang['l_unfinished']		= '完成されていない';
 $lang['l_prefs_set'] 		= 'Your preferences have been set.';
@@ -88,7 +88,6 @@ $lang['l_prefs_unset'] 		= 'Preferences unset. Changes will take place next page
 $lang['l_unset_prefs'] 		= '保存された設定を削除する';
 $lang['l_organizer']		= 'Organizer';
 $lang['l_attendee']			= 'Attendee';
-$lang['l_status']			= 'Status';
 $lang['l_location']			= 'Location';
 $lang['l_admin_header']		= 'PHP iCalendar Administration';
 $lang['l_username']			= 'Username';
@@ -203,4 +202,4 @@ $lang['l_error_invalidcal'] 	= 'Invalid calendar file. Please try a different ca
 $lang['l_error_cantopen'] 		= 'Unable to open calendar.';
 $lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';
 
-?>
\ No newline at end of file
+?>
