@@ -36,6 +36,7 @@ $list_months 	= list_months();
 $list_weeks 	= list_weeks();
 $list_jumps 	= list_jumps();
 $list_calcolors = list_calcolors();
+$list_icals_pick = display_ical_list(availableCalendars($username, $password, $ALL_CALENDARS_COMBINED), TRUE);
 
 // login/logout
 $is_logged_in = ($username != '' && !$invalid_login) ? true : false;
@@ -49,7 +50,8 @@ $page->replace_files(array(
 	'header'			=> BASE.'templates/'.$template.'/header.tpl',
 	'event_js'			=> BASE.'functions/event.js',
 	'footer'			=> BASE.'templates/'.$template.'/footer.tpl',
-	'sidebar'			=> BASE.'templates/'.$template.'/sidebar.tpl'
+        'sidebar'                       => BASE.'templates/'.$template.'/sidebar.tpl',
+        'search_box'                    => BASE.'templates/'.$template.'/search_box.tpl'
 	));
 
 $page->replace_tags(array(
@@ -58,6 +60,7 @@ $page->replace_tags(array(
 	'template'			=> $template,
 	'cal'				=> $cal,
 	'getdate'			=> $getdate,
+        'cpath'                 => $cpath,
 	'calendar_name'		=> $calendar_name,
 	'display_date'		=> $display_date,
 	'current_view'		=> $current_view,
@@ -65,7 +68,7 @@ $page->replace_tags(array(
 	'rss_powered'	 	=> $rss_powered,
 	'rss_available' 	=> '',
 	'rss_valid' 		=> '',
-	'show_search' 		=> '',
+        'show_search'           => $show_search,
 	'next_day' 			=> $next_day,
 	'next_week' 		=> $next_week,
 	'prev_day'	 		=> $prev_day,
@@ -78,6 +81,7 @@ $page->replace_tags(array(
 	'username'			=> $username,
 	'logout_querys'		=> $logout_querys,
 	'list_icals' 		=> $list_icals,
+	'list_icals_pick' 		=> $list_icals_pick,
 	'list_years' 		=> $list_years,
 	'list_months' 		=> $list_months,
 	'list_weeks' 		=> $list_weeks,
@@ -97,6 +101,7 @@ $page->replace_tags(array(
 	'l_year'			=> $lang['l_year'],
 	'l_subscribe'		=> $lang['l_subscribe'],
 	'l_download'		=> $lang['l_download'],
+		'l_search'				=> $lang['l_search'],
 	'l_powered_by'		=> $lang['l_powered_by'],
 	'l_this_site_is'	=> $lang['l_this_site_is']			
 	));
@@ -115,6 +120,10 @@ if ($allow_login == 'yes') {
 	'l_login'			=> $lang['l_login'],
 	'l_logout'			=> $lang['l_logout']
 	));
+}
+
+if ($show_search != 'yes') {
+	$page->nosearch($page);
 }	
 	
 $page->draw_week($page);
